package com.hz.pm.api.projectlib.controller;

import cn.hutool.core.map.MapUtil;
import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import cn.hutool.poi.excel.StyleSet;
import com.hz.pm.api.projectlib.manage.MhSystemReplaceManage;
import com.hz.pm.api.projectlib.model.dto.MhSystemBaseInfoDTO;
import com.hz.pm.api.projectlib.model.req.MhSystemReplaceReq;
import com.ningdatech.basic.model.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.poi.ss.usermodel.CellStyle;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.io.File;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * MhSystemReplaceController
 * </p>
 *
 * @author WendyYang
 * @since 15:10 2024/8/16
 */
@Api(tags = "系统替代情况底账")
@RestController
@RequiredArgsConstructor
@RequestMapping("/api/v1/mh/systemReplace")
public class MhSystemReplaceController {

    private final MhSystemReplaceManage mhSystemReplaceManage;

    @GetMapping("/page")
    @ApiOperation("列表查询")
    public PageVo<MhSystemBaseInfoDTO> page(MhSystemReplaceReq req) {
        return mhSystemReplaceManage.page(req);
    }

    public static void main(String[] args) {
        ExcelReader reader = ExcelUtil.getReader("/Users/wendy/Desktop/信息系统.xlsx");
        List<Map<String, Object>> maps = reader.readAll();
        List<MhSystemBaseInfoDTO> collect = maps.stream().map(w -> {
            MhSystemBaseInfoDTO dto = new MhSystemBaseInfoDTO();
            dto.setSourceName(MapUtil.getStr(w, "系统名称"));
            dto.setTargetName(MapUtil.getStr(w, "替代后系统名称"));
            dto.setBuildOrgName(MapUtil.getStr(w, "建设单位"));
            dto.setBuildOrgCode(MapUtil.getLong(w, "建设单位ID"));
            dto.setReplaceType(MapUtil.getStr(w, "改造方式"));
            dto.setSystemNum(MapUtil.getInt(w, "集成系统数量", 1));
            dto.setPlanStartDate(MapUtil.getInt(w, "计划改造开始时间"));
            dto.setPlanFinishDate(MapUtil.getInt(w, "计划完成时间"));
            dto.setActualStartDate(MapUtil.get(w, "开始时间", LocalDateTime.class));
            dto.setActualFinishDate(MapUtil.get(w, "完成时间", LocalDateTime.class));
            return dto;
        }).collect(Collectors.toList());

        try (ExcelWriter writer = ExcelUtil.getWriter()) {
            writer.write(collect)
                    .flush(new File("/Users/wendy/Desktop/mh-system-replace.xlsx"))
                    .close();
        }

    }

}
