package com.hz.pm.api.projectlib.manage;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.io.resource.ClassPathResource;
import cn.hutool.core.util.StrUtil;
import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import com.hz.pm.api.projectlib.model.dto.MhSystemBaseInfoDTO;
import com.hz.pm.api.projectlib.model.req.MhSystemReplaceReq;
import com.hz.pm.api.user.helper.MhUnitCache;
import com.ningdatech.basic.model.PageVo;
import com.ningdatech.basic.util.CollUtils;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Component;

import java.io.InputStream;
import java.util.Comparator;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * <p>
 * MhSystemReplaceManage
 * </p>
 *
 * @author WendyYang
 * @since 15:11 2024/8/16
 */
@Component
@RequiredArgsConstructor
public class MhSystemReplaceManage {

    private final MhUnitCache mhUnitCache;

    public PageVo<MhSystemBaseInfoDTO> page(MhSystemReplaceReq req) {
        ClassPathResource resource = new ClassPathResource("/response/mh-system-replace.xlsx");
        InputStream stream = resource.getStream();
        ExcelReader reader = ExcelUtil.getReader(stream);
        List<Map<String, Object>> data = reader.readAll();
        List<MhSystemBaseInfoDTO> actualData = BeanUtil.copyToList(data, MhSystemBaseInfoDTO.class);
        List<Long> filterOrgCodes;
        if (req.getBuildOrgCode() != null) {
            filterOrgCodes = mhUnitCache.getViewChildIdsRecursion(req.getBuildOrgCode());
        } else {
            filterOrgCodes = null;
        }
        List<MhSystemBaseInfoDTO> filterData = actualData.stream().filter(w -> {
            if (filterOrgCodes != null && !filterOrgCodes.contains(w.getBuildOrgCode())) {
                return false;
            }
            if (req.getFinish() != null
                    && !req.getFinish() == Objects.nonNull(w.getActualFinishDate())) {
                return false;
            }
            if (StrUtil.isNotBlank(req.getReplaceType())
                    && !req.getReplaceType().equals(w.getReplaceType())) {
                return false;
            }
            if (req.getPlanStartDateMin() != null
                    && req.getPlanStartDateMax() != null
                    && (w.getPlanStartDate() == null
                    || !(w.getPlanStartDate() >= req.getPlanStartDateMin()
                    && w.getPlanStartDate() <= req.getPlanStartDateMax()))) {
                return false;
            }

            if (req.getPlanFinishDateMin() != null
                    && req.getPlanFinishDateMax() != null
                    && (w.getPlanFinishDate() == null
                    || !(w.getPlanFinishDate() >= req.getPlanFinishDateMin()
                    && w.getPlanFinishDate() <= req.getPlanFinishDateMax()))) {
                return false;
            }

            if (StrUtil.isNotBlank(req.getSystemName())
                    && (!w.getSourceName().contains(req.getSystemName())
                    || !w.getTargetName().contains(req.getSystemName()))) {
                return false;
            }

            if (StrUtil.isNotBlank(req.getBuildOrgName())) {
                return w.getBuildOrgName().contains(req.getBuildOrgName());
            }
            return true;
        }).collect(Collectors.toList());
        if (Boolean.TRUE.equals(req.getFinish())) {
            filterData.sort(Comparator.comparing(MhSystemBaseInfoDTO::getActualFinishDate).reversed());
        } else {
            filterData.sort(Comparator.comparing(MhSystemBaseInfoDTO::getPlanFinishDate).reversed());
        }
        List<MhSystemBaseInfoDTO> pageData = CollUtils.page(filterData, req.getPageNumber(), req.getPageSize());
        return PageVo.of(pageData, filterData.size());
    }

}
